/* Generated by wayland-scanner 1.20.0 */

#ifndef TEXT_CLIENT_PROTOCOL_H
#define TEXT_CLIENT_PROTOCOL_H

#include <stdint.h>
#include <stddef.h>
#include "wayland-client.h"

#ifdef  __cplusplus
extern "C" {
#endif

/**
 * @page page_text The text protocol
 * @section page_ifaces_text Interfaces
 * - @subpage page_iface_text_model - text model
 * - @subpage page_iface_text_model_factory - text model factory
 * @section page_copyright_text Copyright
 * <pre>
 *
 * Copyright © 2012 Intel Corporation
 * Copyright © 2013-2020 LG Electronics, Inc.
 *
 * Permission to use, copy, modify, distribute, and sell this
 * software and its documentation for any purpose is hereby granted
 * without fee, provided that the above copyright notice appear in
 * all copies and that both that copyright notice and this permission
 * notice appear in supporting documentation, and that the name of
 * the copyright holders not be used in advertising or publicity
 * pertaining to distribution of the software without specific,
 * written prior permission.  The copyright holders make no
 * representations about the suitability of this software for any
 * purpose.  It is provided "as is" without express or implied
 * warranty.
 *
 * THE COPYRIGHT HOLDERS DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
 * SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS, IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
 * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
 * THIS SOFTWARE.
 * </pre>
 */
struct text_model;
struct text_model_factory;
struct wl_seat;
struct wl_surface;

#ifndef TEXT_MODEL_INTERFACE
#define TEXT_MODEL_INTERFACE
/**
 * @page page_iface_text_model text_model
 * @section page_iface_text_model_desc Description
 *
 * A model for text input. Adds support for text input and input methods to
 * applications. A text_model object is created from a text_model_factory and
 * corresponds typically to a text entry in an application. Requests are used
 * to activate/deactivate the model and set information like surrounding and
 * selected text or the content type. The information about entered text is
 * sent to the model via the pre-edit and commit events. Using this interface
 * removes the need for applications to directly process hardware key events
 * and compose text out of them.
 * @section page_iface_text_model_api API
 * See @ref iface_text_model.
 */
/**
 * @defgroup iface_text_model The text_model interface
 *
 * A model for text input. Adds support for text input and input methods to
 * applications. A text_model object is created from a text_model_factory and
 * corresponds typically to a text entry in an application. Requests are used
 * to activate/deactivate the model and set information like surrounding and
 * selected text or the content type. The information about entered text is
 * sent to the model via the pre-edit and commit events. Using this interface
 * removes the need for applications to directly process hardware key events
 * and compose text out of them.
 */
extern const struct wl_interface text_model_interface;
#endif
#ifndef TEXT_MODEL_FACTORY_INTERFACE
#define TEXT_MODEL_FACTORY_INTERFACE
/**
 * @page page_iface_text_model_factory text_model_factory
 * @section page_iface_text_model_factory_desc Description
 *
 * A factory for text models. This object is a singleton global.
 * @section page_iface_text_model_factory_api API
 * See @ref iface_text_model_factory.
 */
/**
 * @defgroup iface_text_model_factory The text_model_factory interface
 *
 * A factory for text models. This object is a singleton global.
 */
extern const struct wl_interface text_model_factory_interface;
#endif

#ifndef TEXT_MODEL_CONTENT_HINT_ENUM
#define TEXT_MODEL_CONTENT_HINT_ENUM
/**
 * @ingroup iface_text_model
 * content hint
 *
 * Content hint is a bitmask to allow to modify the behavior of the text
 * input.
 */
enum text_model_content_hint {
	/**
	 * no special behaviour
	 */
	TEXT_MODEL_CONTENT_HINT_NONE = 0x0,
	/**
	 * auto completion, correction and capitalization
	 */
	TEXT_MODEL_CONTENT_HINT_DEFAULT = 0x7,
	/**
	 * hidden and sensitive text
	 */
	TEXT_MODEL_CONTENT_HINT_PASSWORD = 0xc0,
	/**
	 * suggest word completions
	 */
	TEXT_MODEL_CONTENT_HINT_AUTO_COMPLETION = 0x1,
	/**
	 * suggest word corrections
	 */
	TEXT_MODEL_CONTENT_HINT_AUTO_CORRECTION = 0x2,
	/**
	 * switch to uppercase letters at the start of a sentence
	 */
	TEXT_MODEL_CONTENT_HINT_AUTO_CAPITALIZATION = 0x4,
	/**
	 * prefer lowercase letters
	 */
	TEXT_MODEL_CONTENT_HINT_LOWERCASE = 0x8,
	/**
	 * prefer uppercase letters
	 */
	TEXT_MODEL_CONTENT_HINT_UPPERCASE = 0x10,
	/**
	 * prefer casing for titles and headings (can be language dependend)
	 */
	TEXT_MODEL_CONTENT_HINT_TITLECASE = 0x20,
	/**
	 * characters should be hidden
	 */
	TEXT_MODEL_CONTENT_HINT_HIDDEN_TEXT = 0x40,
	/**
	 * typed text should not be stored
	 */
	TEXT_MODEL_CONTENT_HINT_SENSITIVE_DATA = 0x80,
	/**
	 * just latin characters should be entered
	 */
	TEXT_MODEL_CONTENT_HINT_LATIN = 0x100,
	/**
	 * the text input is multiline
	 */
	TEXT_MODEL_CONTENT_HINT_MULTILINE = 0x200,
};
#endif /* TEXT_MODEL_CONTENT_HINT_ENUM */

#ifndef TEXT_MODEL_CONTENT_PURPOSE_ENUM
#define TEXT_MODEL_CONTENT_PURPOSE_ENUM
/**
 * @ingroup iface_text_model
 * content purpose
 *
 * The content purpose allows to specify the primary purpose of a text input.
 *
 * This allows an input method to show special purpose input panels with extra
 * characters or to disallow some characters.
 */
enum text_model_content_purpose {
	/**
	 * default input, allowing all characters
	 */
	TEXT_MODEL_CONTENT_PURPOSE_NORMAL = 0,
	/**
	 * allow only alphabetic characters
	 */
	TEXT_MODEL_CONTENT_PURPOSE_ALPHA = 1,
	/**
	 * allow only digits
	 */
	TEXT_MODEL_CONTENT_PURPOSE_DIGITS = 2,
	/**
	 * input a number (including decimal separator and sign)
	 */
	TEXT_MODEL_CONTENT_PURPOSE_NUMBER = 3,
	/**
	 * input a phone number
	 */
	TEXT_MODEL_CONTENT_PURPOSE_PHONE = 4,
	/**
	 * input an URL
	 */
	TEXT_MODEL_CONTENT_PURPOSE_URL = 5,
	/**
	 * input an email address
	 */
	TEXT_MODEL_CONTENT_PURPOSE_EMAIL = 6,
	/**
	 * input a name of a person
	 */
	TEXT_MODEL_CONTENT_PURPOSE_NAME = 7,
	/**
	 * input a password (combine with password or sensitive_data hint)
	 */
	TEXT_MODEL_CONTENT_PURPOSE_PASSWORD = 8,
	/**
	 * input a date
	 */
	TEXT_MODEL_CONTENT_PURPOSE_DATE = 9,
	/**
	 * input a time
	 */
	TEXT_MODEL_CONTENT_PURPOSE_TIME = 10,
	/**
	 * input a date and time
	 */
	TEXT_MODEL_CONTENT_PURPOSE_DATETIME = 11,
	/**
	 * input for a terminal
	 */
	TEXT_MODEL_CONTENT_PURPOSE_TERMINAL = 12,
};
#endif /* TEXT_MODEL_CONTENT_PURPOSE_ENUM */

#ifndef TEXT_MODEL_ENTER_KEY_TYPE_ENUM
#define TEXT_MODEL_ENTER_KEY_TYPE_ENUM
/**
 * @ingroup iface_text_model
 * enter key type
 *
 * The enter key type can be used to alter the appearance of the enter key
 * on an input panel (virtual keyboard).
 */
enum text_model_enter_key_type {
	/**
	 * the default Enter key
	 */
	TEXT_MODEL_ENTER_KEY_TYPE_DEFAULT = 0,
	/**
	 * show a Return button that inserts a new line
	 */
	TEXT_MODEL_ENTER_KEY_TYPE_RETURN = 1,
	/**
	 * show a Done button
	 */
	TEXT_MODEL_ENTER_KEY_TYPE_DONE = 2,
	/**
	 * show a Go button
	 */
	TEXT_MODEL_ENTER_KEY_TYPE_GO = 3,
	/**
	 * show a Send button
	 */
	TEXT_MODEL_ENTER_KEY_TYPE_SEND = 4,
	/**
	 * show a Search button
	 */
	TEXT_MODEL_ENTER_KEY_TYPE_SEARCH = 5,
	/**
	 * show a Next button
	 */
	TEXT_MODEL_ENTER_KEY_TYPE_NEXT = 6,
	/**
	 * show a Previous button
	 */
	TEXT_MODEL_ENTER_KEY_TYPE_PREVIOUS = 7,
};
#endif /* TEXT_MODEL_ENTER_KEY_TYPE_ENUM */

#ifndef TEXT_MODEL_PREEDIT_STYLE_ENUM
#define TEXT_MODEL_PREEDIT_STYLE_ENUM
/**
 * @ingroup iface_text_model
 * pre-edit style
 *
 * The style for a composing text text.
 */
enum text_model_preedit_style {
	TEXT_MODEL_PREEDIT_STYLE_DEFAULT = 1,
	TEXT_MODEL_PREEDIT_STYLE_ACTIVE = 2,
	TEXT_MODEL_PREEDIT_STYLE_INACTIVE = 3,
	TEXT_MODEL_PREEDIT_STYLE_HIGHLIGHT = 4,
	TEXT_MODEL_PREEDIT_STYLE_UNDERLINE = 5,
	TEXT_MODEL_PREEDIT_STYLE_SELECTION = 6,
	TEXT_MODEL_PREEDIT_STYLE_INCORRECT = 7,
};
#endif /* TEXT_MODEL_PREEDIT_STYLE_ENUM */

/**
 * @ingroup iface_text_model
 * @struct text_model_listener
 */
struct text_model_listener {
	/**
	 * text to commit
	 *
	 * Notifies when text should be inserted into the editor widget.
	 * The text to commit could be either just a single character after
	 * a key press or the result of some composing (pre-edit). It also
	 * sets the new cursor position (as byte index) relative to the
	 * inserted text.
	 *
	 * Any previously set composing text should be removed.
	 */
	void (*commit_string)(void *data,
			      struct text_model *text_model,
			      uint32_t serial,
			      const char *text);
	/**
	 * pre-edit text
	 *
	 * Notifies when a new composing text (pre-edit) should be set
	 * around the current cursor position. Any previously set composing
	 * text should be removed.
	 *
	 * The commit text can be used to replace the preedit text on reset
	 * (for example on unfocus).
	 */
	void (*preedit_string)(void *data,
			       struct text_model *text_model,
			       uint32_t serial,
			       const char *text,
			       const char *commit);
	/**
	 * delete surrounding text
	 *
	 * Notifies when the text around the current cursor position
	 * should be deleted. Index is relative to the current cursor (as
	 * byte index). Length is the length of deleted text (as bytes).
	 */
	void (*delete_surrounding_text)(void *data,
					struct text_model *text_model,
					uint32_t serial,
					int32_t index,
					uint32_t length);
	/**
	 * set cursor to new position
	 *
	 * Notifies when the cursor or anchor position should be
	 * modified. It should take effect after the next commit_string
	 * event.
	 *
	 * Not implemented.
	 */
	void (*cursor_position)(void *data,
				struct text_model *text_model,
				uint32_t serial,
				int32_t index,
				int32_t anchor);
	/**
	 * pre-edit styling
	 *
	 * Sets styling information on composing text. The style is
	 * applied for length (in bytes) characters from index relative to
	 * the beginning of the composing text (as byte index). Multiple
	 * styles can be applied to a composing text.
	 *
	 * This event should be handled as part of a following
	 * preedit_string event.
	 */
	void (*preedit_styling)(void *data,
				struct text_model *text_model,
				uint32_t serial,
				uint32_t index,
				uint32_t length,
				uint32_t style);
	/**
	 * pre-edit cursor
	 *
	 * Sets the cursor position inside the composing text (as byte
	 * index) relative to the start of the composing text.
	 *
	 * This event should be handled as part of a following
	 * preedit_string event.
	 */
	void (*preedit_cursor)(void *data,
			       struct text_model *text_model,
			       uint32_t serial,
			       int32_t index);
	/**
	 * modifiers map
	 *
	 * Transfers an array of 0-terminated modifiers names. The
	 * position in the array is the index of the modifier as used in
	 * the modifiers bitmask in the keysym event.
	 */
	void (*modifiers_map)(void *data,
			      struct text_model *text_model,
			      struct wl_array *map);
	/**
	 * keysym
	 *
	 * Notifies when a key event was sent. Key events should not be
	 * used for normal text input operations, which should be done with
	 * commit_string, delete_surrounding_text, etc. The key event
	 * follows the wl_keyboard key event convention. State is a XKB
	 * keysym, state a wl_keyboard key_state. Modifiers are a mask for
	 * effective modifiers (where the modfier indices are set by the
	 * modifiers_map event)
	 */
	void (*keysym)(void *data,
		       struct text_model *text_model,
		       uint32_t serial,
		       uint32_t time,
		       uint32_t sym,
		       uint32_t state,
		       uint32_t modifiers);
	/**
	 * enter event
	 *
	 * Notifies the model when it is activated on a given surface.
	 * Typically in response to an activate request.
	 */
	void (*enter)(void *data,
		      struct text_model *text_model,
		      struct wl_surface *surface);
	/**
	 * leave event
	 *
	 * Notifies the model when it is deactivated. Either in response
	 * to a deactivate request or when the assigned surface lost focus
	 * or was destroyed.
	 */
	void (*leave)(void *data,
		      struct text_model *text_model);
	/**
	 * state of the input panel
	 *
	 * Notifies when the visibility state of the input panel changed.
	 * The state is either 0 (hidden) or 1 (shown).
	 */
	void (*input_panel_state)(void *data,
				  struct text_model *text_model,
				  uint32_t state);
	/**
	 * rect of the input panel
	 *
	 * Notifies when the geometry of the input panel changes in
	 * surface local coordinates.
	 */
	void (*input_panel_rect)(void *data,
				 struct text_model *text_model,
				 int32_t x,
				 int32_t y,
				 uint32_t width,
				 uint32_t height);
};

/**
 * @ingroup iface_text_model
 */
static inline int
text_model_add_listener(struct text_model *text_model,
			const struct text_model_listener *listener, void *data)
{
	return wl_proxy_add_listener((struct wl_proxy *) text_model,
				     (void (**)(void)) listener, data);
}

#define TEXT_MODEL_SET_SURROUNDING_TEXT 0
#define TEXT_MODEL_ACTIVATE 1
#define TEXT_MODEL_DEACTIVATE 2
#define TEXT_MODEL_RESET 3
#define TEXT_MODEL_SET_CURSOR_RECTANGLE 4
#define TEXT_MODEL_SET_CONTENT_TYPE 5
#define TEXT_MODEL_INVOKE_ACTION 6
#define TEXT_MODEL_COMMIT 7
#define TEXT_MODEL_SHOW_INPUT_PANEL 8
#define TEXT_MODEL_HIDE_INPUT_PANEL 9
#define TEXT_MODEL_SET_MAX_TEXT_LENGTH 10
#define TEXT_MODEL_SET_PLATFORM_DATA 11
#define TEXT_MODEL_SET_ENTER_KEY_TYPE 12
#define TEXT_MODEL_SET_INPUT_PANEL_RECT 13
#define TEXT_MODEL_RESET_INPUT_PANEL_RECT 14

/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_COMMIT_STRING_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_PREEDIT_STRING_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_DELETE_SURROUNDING_TEXT_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_CURSOR_POSITION_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_PREEDIT_STYLING_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_PREEDIT_CURSOR_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_MODIFIERS_MAP_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_KEYSYM_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_ENTER_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_LEAVE_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_INPUT_PANEL_STATE_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_INPUT_PANEL_RECT_SINCE_VERSION 1

/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_SET_SURROUNDING_TEXT_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_ACTIVATE_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_DEACTIVATE_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_RESET_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_SET_CURSOR_RECTANGLE_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_SET_CONTENT_TYPE_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_INVOKE_ACTION_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_COMMIT_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_SHOW_INPUT_PANEL_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_HIDE_INPUT_PANEL_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_SET_MAX_TEXT_LENGTH_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_SET_PLATFORM_DATA_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_SET_ENTER_KEY_TYPE_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_SET_INPUT_PANEL_RECT_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_RESET_INPUT_PANEL_RECT_SINCE_VERSION 1

/** @ingroup iface_text_model */
static inline void
text_model_set_user_data(struct text_model *text_model, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) text_model, user_data);
}

/** @ingroup iface_text_model */
static inline void *
text_model_get_user_data(struct text_model *text_model)
{
	return wl_proxy_get_user_data((struct wl_proxy *) text_model);
}

static inline uint32_t
text_model_get_version(struct text_model *text_model)
{
	return wl_proxy_get_version((struct wl_proxy *) text_model);
}

/** @ingroup iface_text_model */
static inline void
text_model_destroy(struct text_model *text_model)
{
	wl_proxy_destroy((struct wl_proxy *) text_model);
}

/**
 * @ingroup iface_text_model
 *
 * Sets the plain surrounding text around the input position. Cursor is the
 * byte index within the surrounding text. Anchor is the byte index of the
 * selection anchor within the surrounding text. If there is no selected
 * text anchor is the same as cursor.
 */
static inline void
text_model_set_surrounding_text(struct text_model *text_model, const char *text, uint32_t cursor, uint32_t anchor)
{
	wl_proxy_marshal_flags((struct wl_proxy *) text_model,
			 TEXT_MODEL_SET_SURROUNDING_TEXT, NULL, wl_proxy_get_version((struct wl_proxy *) text_model), 0, text, cursor, anchor);
}

/**
 * @ingroup iface_text_model
 *
 * Requests the model to be activated (typically when the text entry gets
 * focus). The seat argument is a wl_seat which maintains the focus for
 * this activation. The surface argument is a wl_surface assigned to the
 * model and tracked for focus lost. The activated event is emitted on
 * successful activation.
 */
static inline void
text_model_activate(struct text_model *text_model, uint32_t serial, struct wl_seat *seat, struct wl_surface *surface)
{
	wl_proxy_marshal_flags((struct wl_proxy *) text_model,
			 TEXT_MODEL_ACTIVATE, NULL, wl_proxy_get_version((struct wl_proxy *) text_model), 0, serial, seat, surface);
}

/**
 * @ingroup iface_text_model
 *
 * Requests the model to be deactivated (typically when the text entry
 * lost focus). The seat argument is a wl_seat which was used for
 * activation.
 */
static inline void
text_model_deactivate(struct text_model *text_model, struct wl_seat *seat)
{
	wl_proxy_marshal_flags((struct wl_proxy *) text_model,
			 TEXT_MODEL_DEACTIVATE, NULL, wl_proxy_get_version((struct wl_proxy *) text_model), 0, seat);
}

/**
 * @ingroup iface_text_model
 *
 * Should be called by an editor widget when the input state should
 * be reset, for example after the text was changed outside of the
 * normal input method flow.
 */
static inline void
text_model_reset(struct text_model *text_model, uint32_t serial)
{
	wl_proxy_marshal_flags((struct wl_proxy *) text_model,
			 TEXT_MODEL_RESET, NULL, wl_proxy_get_version((struct wl_proxy *) text_model), 0, serial);
}

/**
 * @ingroup iface_text_model
 *
 * Sets a rectangle for the cursor with x, y, width and height in surface
 * local coordinates.
 *
 * Not implemented.
 */
static inline void
text_model_set_cursor_rectangle(struct text_model *text_model, int32_t x, int32_t y, int32_t width, int32_t height)
{
	wl_proxy_marshal_flags((struct wl_proxy *) text_model,
			 TEXT_MODEL_SET_CURSOR_RECTANGLE, NULL, wl_proxy_get_version((struct wl_proxy *) text_model), 0, x, y, width, height);
}

/**
 * @ingroup iface_text_model
 *
 * Sets the content purpose and content hint. While the purpose is the
 * basic purpose of an input field, the hint flags allow to modify some
 * of the behavior.
 *
 * When no content type is explicitly set, a normal content purpose with
 * default hints (auto completion, auto correction, auto capitalization)
 * should be assumed.
 */
static inline void
text_model_set_content_type(struct text_model *text_model, uint32_t hint, uint32_t purpose)
{
	wl_proxy_marshal_flags((struct wl_proxy *) text_model,
			 TEXT_MODEL_SET_CONTENT_TYPE, NULL, wl_proxy_get_version((struct wl_proxy *) text_model), 0, hint, purpose);
}

/**
 * @ingroup iface_text_model
 *
 * Invokes a button action on a given position.
 *
 * Not implemented.
 */
static inline void
text_model_invoke_action(struct text_model *text_model, uint32_t button, uint32_t index)
{
	wl_proxy_marshal_flags((struct wl_proxy *) text_model,
			 TEXT_MODEL_INVOKE_ACTION, NULL, wl_proxy_get_version((struct wl_proxy *) text_model), 0, button, index);
}

/**
 * @ingroup iface_text_model
 *
 * Requests to apply state changes sent so far.
 */
static inline void
text_model_commit(struct text_model *text_model)
{
	wl_proxy_marshal_flags((struct wl_proxy *) text_model,
			 TEXT_MODEL_COMMIT, NULL, wl_proxy_get_version((struct wl_proxy *) text_model), 0);
}

/**
 * @ingroup iface_text_model
 *
 * Requests input panels (virtual keyboard) to show.
 */
static inline void
text_model_show_input_panel(struct text_model *text_model)
{
	wl_proxy_marshal_flags((struct wl_proxy *) text_model,
			 TEXT_MODEL_SHOW_INPUT_PANEL, NULL, wl_proxy_get_version((struct wl_proxy *) text_model), 0);
}

/**
 * @ingroup iface_text_model
 *
 * Requests input panels (virtual keyboard) to hide.
 */
static inline void
text_model_hide_input_panel(struct text_model *text_model)
{
	wl_proxy_marshal_flags((struct wl_proxy *) text_model,
			 TEXT_MODEL_HIDE_INPUT_PANEL, NULL, wl_proxy_get_version((struct wl_proxy *) text_model), 0);
}

/**
 * @ingroup iface_text_model
 *
 * Sets the maximum length of an input field.
 */
static inline void
text_model_set_max_text_length(struct text_model *text_model, uint32_t length)
{
	wl_proxy_marshal_flags((struct wl_proxy *) text_model,
			 TEXT_MODEL_SET_MAX_TEXT_LENGTH, NULL, wl_proxy_get_version((struct wl_proxy *) text_model), 0, length);
}

/**
 * @ingroup iface_text_model
 *
 * Sets the platform specific data (text).
 */
static inline void
text_model_set_platform_data(struct text_model *text_model, const char *text)
{
	wl_proxy_marshal_flags((struct wl_proxy *) text_model,
			 TEXT_MODEL_SET_PLATFORM_DATA, NULL, wl_proxy_get_version((struct wl_proxy *) text_model), 0, text);
}

/**
 * @ingroup iface_text_model
 *
 * Sets the type of the enter key on an input panel (virtual keyboard).
 */
static inline void
text_model_set_enter_key_type(struct text_model *text_model, uint32_t enter_key_type)
{
	wl_proxy_marshal_flags((struct wl_proxy *) text_model,
			 TEXT_MODEL_SET_ENTER_KEY_TYPE, NULL, wl_proxy_get_version((struct wl_proxy *) text_model), 0, enter_key_type);
}

/**
 * @ingroup iface_text_model
 *
 * Requests the geometry of the input panel to change. The geometry should
 * be in surface local coordinates.
 */
static inline void
text_model_set_input_panel_rect(struct text_model *text_model, int32_t x, int32_t y, uint32_t width, uint32_t height)
{
	wl_proxy_marshal_flags((struct wl_proxy *) text_model,
			 TEXT_MODEL_SET_INPUT_PANEL_RECT, NULL, wl_proxy_get_version((struct wl_proxy *) text_model), 0, x, y, width, height);
}

/**
 * @ingroup iface_text_model
 *
 * Resets the geometry of the input panel requested.
 */
static inline void
text_model_reset_input_panel_rect(struct text_model *text_model)
{
	wl_proxy_marshal_flags((struct wl_proxy *) text_model,
			 TEXT_MODEL_RESET_INPUT_PANEL_RECT, NULL, wl_proxy_get_version((struct wl_proxy *) text_model), 0);
}

#define TEXT_MODEL_FACTORY_CREATE_TEXT_MODEL 0


/**
 * @ingroup iface_text_model_factory
 */
#define TEXT_MODEL_FACTORY_CREATE_TEXT_MODEL_SINCE_VERSION 1

/** @ingroup iface_text_model_factory */
static inline void
text_model_factory_set_user_data(struct text_model_factory *text_model_factory, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) text_model_factory, user_data);
}

/** @ingroup iface_text_model_factory */
static inline void *
text_model_factory_get_user_data(struct text_model_factory *text_model_factory)
{
	return wl_proxy_get_user_data((struct wl_proxy *) text_model_factory);
}

static inline uint32_t
text_model_factory_get_version(struct text_model_factory *text_model_factory)
{
	return wl_proxy_get_version((struct wl_proxy *) text_model_factory);
}

/** @ingroup iface_text_model_factory */
static inline void
text_model_factory_destroy(struct text_model_factory *text_model_factory)
{
	wl_proxy_destroy((struct wl_proxy *) text_model_factory);
}

/**
 * @ingroup iface_text_model_factory
 *
 * Creates a new text model object.
 */
static inline struct text_model *
text_model_factory_create_text_model(struct text_model_factory *text_model_factory)
{
	struct wl_proxy *id;

	id = wl_proxy_marshal_flags((struct wl_proxy *) text_model_factory,
			 TEXT_MODEL_FACTORY_CREATE_TEXT_MODEL, &text_model_interface, wl_proxy_get_version((struct wl_proxy *) text_model_factory), 0, NULL);

	return (struct text_model *) id;
}

#ifdef  __cplusplus
}
#endif

#endif
